@@ -19,19 +19,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "thumbnailviewhelper.moc"
+#include "thumbnailviewhelper.h"
 
 #include <config-gwenview.h>
 
 // Qt
 #include <QAction>
 #include <QCursor>
+#include <QDebug>
+#include <QMenu>
 
 // KDE
 #include <KActionCollection>
-#include <KDebug>
-#include <KLocale>
-#include <KMenu>
 
 // Local
 #include <lib/document/documentfactory.h>
@@ -43,13 +42,13 @@ namespace Gwenview
 struct ThumbnailViewHelperPrivate
 {
     KActionCollection* mActionCollection;
-    KUrl mCurrentDirUrl;
+    QUrl mCurrentDirUrl;
 
-    void addActionToMenu(KMenu& popup, const char* name)
+    void addActionToMenu(QMenu& popup, const char* name)
     {
         QAction* action = mActionCollection->action(name);
         if (!action) {
-            kWarning() << "Unknown action" << name;
+            qWarning() << "Unknown action" << name;
             return;
         }
         if (action->isEnabled()) {
@@ -70,15 +69,15 @@ ThumbnailViewHelper::~ThumbnailViewHelper()
     delete d;
 }
 
-void ThumbnailViewHelper::setCurrentDirUrl(const KUrl& url)
+void ThumbnailViewHelper::setCurrentDirUrl(const QUrl &url)
 {
     d->mCurrentDirUrl = url;
 }
 
 void ThumbnailViewHelper::showContextMenu(QWidget* parent)
 {
-    KMenu popup(parent);
-    if (d->mCurrentDirUrl.protocol() == "trash") {
+    QMenu popup(parent);
+    if (d->mCurrentDirUrl.scheme() == "trash") {
         d->addActionToMenu(popup, "file_restore");
         d->addActionToMenu(popup, "file_delete");
         popup.addSeparator();
@@ -104,12 +103,12 @@ void ThumbnailViewHelper::showContextMenu(QWidget* parent)
     popup.exec(QCursor::pos());
 }
 
-void ThumbnailViewHelper::showMenuForUrlDroppedOnViewport(QWidget* parent, const KUrl::List& lst)
+void ThumbnailViewHelper::showMenuForUrlDroppedOnViewport(QWidget* parent, const QList<QUrl>& lst)
 {
     showMenuForUrlDroppedOnDir(parent, lst, d->mCurrentDirUrl);
 }
 
-void ThumbnailViewHelper::showMenuForUrlDroppedOnDir(QWidget* parent, const KUrl::List& urlList, const KUrl& destUrl)
+void ThumbnailViewHelper::showMenuForUrlDroppedOnDir(QWidget* parent, const QList<QUrl>& urlList, const QUrl &destUrl)
 {
     FileOperations::showMenuForDroppedUrls(parent, urlList, destUrl);
 }
