@@ -19,13 +19,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "tagmodel.moc"
+#include "tagmodel.h"
 
 // Qt
 
 // KDE
-#include <KDebug>
-#include <KIcon>
+#include <QDebug>
+#include <QIcon>
 
 // Local
 #include "abstractsemanticinfobackend.h"
@@ -44,7 +44,7 @@ static QStandardItem* createItem(const SemanticInfoTag& tag, const QString& labe
     item->setData(tag, TagModel::TagRole);
     item->setData(label.toLower(), TagModel::SortRole);
     item->setData(status, TagModel::AssignmentStatusRole);
-    item->setData(KIcon("mail-tagged.png"), Qt::DecorationRole);
+    item->setData(QIcon::fromTheme("mail-tagged"), Qt::DecorationRole);
     return item;
 }
 
