@@ -19,15 +19,15 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "itemeditor.moc"
+#include "itemeditor.h"
 
 // Qt
 #include <QApplication>
 #include <QShowEvent>
+#include <QDebug>
+#include <QMimeDatabase>
 
 // KDE
-#include <KDebug>
-#include <KMimeType>
 
 // Local
 
@@ -44,7 +44,7 @@ ItemEditor::ItemEditor(QWidget* parent)
 , d(new ItemEditorPrivate)
 {
     setPalette(QApplication::palette());
-    connect(this, SIGNAL(textChanged(QString)), SLOT(resizeToContents()));
+    connect(this, &ItemEditor::textChanged, this, &ItemEditor::resizeToContents);
     setTrapReturnKey(true);
 }
 
@@ -56,7 +56,8 @@ ItemEditor::~ItemEditor()
 void ItemEditor::showEvent(QShowEvent* event)
 {
     // We can't do this in PreviewItemDelegate::updateEditorGeometry() because QAbstractItemView outsmarts us by calling selectAll() on the editor if it is a QLineEdit
-    const QString extension = KMimeType::extractKnownExtension(text());
+    QMimeDatabase db;
+    const QString extension = db.suffixForFileName(text());
     if (!extension.isEmpty()) {
         // The filename contains an extension. Assure that only the filename
         // gets selected.
